@@ -136,12 +136,11 @@ Engine::play(int row)
 			Media media = getInfos(row);
 
 			QString s;
-			QFileInfo fi(listUris[row]);
 			// If the file doesn't have infos, use filename instead
-			if (media.title.isEmpty() || media.artist.isEmpty())
+			if (media.artist.isEmpty())
 			{
-				s = fi.fileName() + "\n";
-				parent->ui->setWindowTitle(fi.fileName());
+				s = media.title + "\n";
+				parent->ui->setWindowTitle(media.title);
 			}
 			else
 			{
@@ -254,7 +253,11 @@ Engine::metaInfosUpdated(Phonon::State newState, Phonon::State oldState)
 		// get infos
 	media.title = metaData.value("TITLE");
 	if (media.title == "")
-	  media.title = mediaObjectForMetaInfos->currentSource().fileName();
+	{
+	  int nn=listSources.indexOf(mediaObjectForMetaInfos->currentSource());
+	  QFileInfo fi(listUris[nn]);
+	  media.title = fi.fileName();
+	}
 	media.artist = metaData.value("ARTIST");
 	media.album = metaData.value("ALBUM");
 	media.totalTime = Engine::msToString(mediaObjectForMetaInfos->totalTime());
