@@ -34,8 +34,8 @@ class UIFolder : public QWidget
 		 */
 		void slotReplFolder();
 		
-	protected:
-		void contextMenuEvent(QContextMenuEvent* event);
+	//protected:
+		//void contextMenuEvent(QContextMenuEvent* event);
 
 	private:
 		QListWidget* listWidget;
@@ -44,16 +44,16 @@ class UIFolder : public QWidget
                 QHBoxLayout* layoutControlF;
                 QVBoxLayout* layout;
 
-		QMenu* folderMenu;
-		QAction* actAddFolder;
-		QAction* actReplFolder;
+// 		QMenu* folderMenu;
+// 		QAction* actAddFolder;
+// 		QAction* actReplFolder;
 
 		QString musicPath;
 		QStringList dirContent;
 
 		QStringList filters;
 
-		void refreshDirContent();
+		int refreshDirContent();
 
 		void addFile(QString uri);
 		void addFolder(QString uri);
