@@ -11,6 +11,7 @@ UISettings::UISettings(UPlay* parent, QString& musicPath)
 	buttonSave = new QPushButton("Save");
 	buttonDir = new QPushButton("Browse");
 	labelDirectory = new QLabel("Music directory :");
+	savePlaylistOnQuit = new QCheckBox("Save playlist on quit");
 	//buttonSave->setFixedHeight(30);
 
 	layout = new QVBoxLayout;
@@ -19,7 +20,12 @@ UISettings::UISettings(UPlay* parent, QString& musicPath)
 	Hlayout->addWidget(directory);
 	Hlayout->addWidget(buttonDir);
 	layout->addLayout(Hlayout);
-	layout->addWidget(buttonSave);
+	layout->addWidget(savePlaylistOnQuit);
+	saveHlayout = new QHBoxLayout;
+	saveHlayout->addWidget(buttonSave);
+	saveHlayout->addStretch();
+	layout->addStretch();
+	layout->addLayout(saveHlayout);
 	layout->setAlignment(Qt::AlignCenter);
 
 	connect(buttonSave, SIGNAL(clicked()), SLOT(saveConf()));
@@ -30,6 +36,20 @@ UISettings::UISettings(UPlay* parent, QString& musicPath)
 
 UISettings::~UISettings()
 {
+  if (buttonSave)
+	delete buttonSave;
+  if (directory)
+	delete directory;
+  if (savePlaylistOnQuit)
+	 delete savePlaylistOnQuit;
+  if (labelDirectory)
+	  delete labelDirectory;
+  if (Hlayout)
+	  delete Hlayout;
+  if (saveHlayout)
+	  delete saveHlayout;
+  if (layout)
+	  delete layout;
 
 }
 
