@@ -28,11 +28,21 @@ class UISettings : public QWidget
 		/*
 		 * Set the label for the music directory editbox
 		 */
-		void
-		setDirectory(QString s)
+		void setDirectory(QString s)
 		{
 			directory->setText(s);
 		}
+		bool getSavePlaylistOnQuitState()
+		{
+		  return savePlaylistOnQuit->isChecked();
+		}
+		void setSavePlaylistOnQuitState(bool save)
+		{
+		  if(save)
+		    savePlaylistOnQuit->setCheckState(Qt::Checked);
+		  else
+		    savePlaylistOnQuit->setCheckState(Qt::Unchecked);
+		}
 		
 	public slots:
 		void saveConf();
@@ -44,7 +54,9 @@ class UISettings : public QWidget
 		QPushButton* buttonDir;
 		QHBoxLayout* Hlayout;
 		QVBoxLayout* layout;
+		QHBoxLayout* saveHlayout;
 		QLabel* labelDirectory;
+		QCheckBox *savePlaylistOnQuit;
 
 		UPlay* parent;
 };
